/***************************************************************************
 *   Copyright 2007 by Marco Martin <notmart@gmail.com>                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .        *
 ***************************************************************************/

#include "svgpaneltest.h"

//QT
#include <QGraphicsSceneDragDropEvent>
#include <QDesktopWidget>
#include <QApplication>

//KDE
#include <KDebug>
#include <KLocale>
#include <KIconLoader>
#include <KMimeType>
#include <KRun>
#include <KSharedConfig>
#include <KMessageBox>
#include <KUrl>

#include <plasma/containment.h>

namespace Plasma
{

SvgPanelTest::SvgPanelTest(QObject *parent, const QVariantList &args)
    : Plasma::Applet(parent, args),
      m_dialog(0)
{
}

SvgPanelTest::~SvgPanelTest()
{
}

void SvgPanelTest::init()
{
    KConfigGroup cg = config();
    m_SvgFileName = cg.readEntry("svgFileName", "widgets/background");
    m_DrawTop = cg.readEntry("DrawTop", true);
    m_DrawBottom = cg.readEntry("DrawBottom", true);
    m_DrawLeft = cg.readEntry("DrawLeft", true);
    m_DrawRight = cg.readEntry("DrawRight", true);

    m_panel = new SvgPanel(m_SvgFileName, this);
    updateFlags();
    setDrawStandardBackground(false);
    setHasConfigurationInterface(true);
}

Qt::Orientations SvgPanelTest::expandingDirections() const
{
    return 0;
}


void SvgPanelTest::paintInterface(QPainter *painter, const QStyleOptionGraphicsItem *option,
                            const QRect &contents)
{
    m_panel->paint(painter, QPoint(0,0));
}


void SvgPanelTest::constraintsUpdated(Plasma::Constraints constraints)
{
    setDrawStandardBackground(false);

    if (constraints & Plasma::SizeConstraint && m_panel) {
        m_panel->resize(contentSize());
    }

    updateGeometry();
}

void SvgPanelTest::showConfigurationInterface()
{
    if (m_dialog == 0) {
        m_dialog = new KDialog;
        m_dialog->setCaption( i18nc("@title:window","Configure SvgPanelTest") );

        QWidget *widget = new QWidget;
        ui.setupUi(widget);
        m_dialog->setMainWidget(widget);
        m_dialog->setButtons( KDialog::Ok | KDialog::Cancel | KDialog::Apply );
        connect( m_dialog, SIGNAL(applyClicked()), this, SLOT(configAccepted()) );
        connect( m_dialog, SIGNAL(okClicked()), this, SLOT(configAccepted()) );

    }

    ui.svgFileName->setUrl(m_SvgFileName);
    ui.drawTop->setChecked(m_DrawTop);
    ui.drawBottom->setChecked(m_DrawBottom);
    ui.drawLeft->setChecked(m_DrawLeft);
    ui.drawRight->setChecked(m_DrawRight);

    m_dialog->show();
}

void SvgPanelTest::configAccepted()
{
    KConfigGroup cg = config();
    m_SvgFileName = ui.svgFileName->url().path();

    m_DrawTop = ui.drawTop->isChecked();
    m_DrawBottom = ui.drawBottom->isChecked();
    m_DrawLeft = ui.drawLeft->isChecked();
    m_DrawRight = ui.drawRight->isChecked();

    cg.writeEntry("svgFileName", m_SvgFileName);
    cg.writeEntry("DrawTop", m_DrawTop);
    cg.writeEntry("DrawBottom", m_DrawBottom);
    cg.writeEntry("DrawLeft", m_DrawLeft);
    cg.writeEntry("DrawRight", m_DrawRight);

    m_panel->setFile(m_SvgFileName);
    updateFlags();

    update();
    emit configNeedsSaving();
}

void SvgPanelTest::updateFlags()
{
    m_panel->setBorderFlags(
                SvgPanel::BorderFlags(
                    (m_DrawTop?SvgPanel::DrawTop:0) |
                    (m_DrawBottom?SvgPanel::DrawBottom:0) |
                    (m_DrawLeft?SvgPanel::DrawLeft:0) |
                    (m_DrawRight?SvgPanel::DrawRight:0)));
}

} // Plasma namespace

#include "svgpaneltest.moc"

